@@ -132,15 +132,16 @@ class ExecutionPoller:
 
     def update_status(self):
         """Update status and return .done attribute value"""
+        self.gd.login()
         url = _url(self.gd.domain, self.poll_url.lstrip("/"))
         response = self.gd.session.get(url, headers=self.gd.headers)
         status = response.json().get("execution", {}).get("status")
         if status is None:
             raise Exception(response.text)
         self.status = status
-        if self.status == "DONE":
+        if self.status in ["DONE", "OK"]:
             self.done = True
-        elif self.status == "RUNNING":
+        elif self.status in ["RUNNING", "SCHEDULED"]:
             self.done = False
         else:
             raise Exception(f"Execution status is prohibited: {self.status}")
